@@ -160,13 +160,15 @@ from typing import Any, Dict, List, Optional, Sequence, Tuple, Union, cast
 import setuptools                                                                                       # type: ignore
 from setuptools.config import read_configuration                                                        # type: ignore
 
+# import unreferenced vars (BUILD_CONFIG_FILE, DOCS_FOLDER, TEMPLATES_FOLDER, TESTS_FOLDER) to ensure for incomplete pev
+# .. maps a non-empty default value if determined via pev_str().
 # noinspection PyUnresolvedReferences
-from ae.base import (   # type: ignore # noqa: F401 # pylint:disable=unused-import
+from ae.base import (                                       # type: ignore # noqa: F401 # pylint:disable=unused-import
     BUILD_CONFIG_FILE, DOCS_FOLDER, PY_EXT, PY_INIT, TEMPLATES_FOLDER, TESTS_FOLDER,
     in_wd, norm_path, project_main_file, read_file)
 
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 
 
 APP_PRJ = 'app'                                             #: gui application project
@@ -190,8 +192,8 @@ REPO_CODE_DOMAIN = 'gitlab.com'                             #: code repository d
 REPO_PAGES_DOMAIN = 'gitlab.io'                             #: repository pages internet/dns domain
 REPO_GROUP_SUFFIX = '-group'                                #: repository users group name suffix
 
-REQ_FILE_NAME = 'requirements.txt'                          #: default file name for all/dev requirements
-REQ_TEST_FILE_NAME = 'test_requirements.txt'                #: default file name for test requirements
+REQ_FILE_NAME = 'requirements.txt'                          #: requirements default file name
+REQ_DEV_FILE_NAME = 'dev_requirements.txt'                  #: default file name for development/template requirements
 
 # STK_* constants holding default values of supported setuptools setup() keyword arguments
 STK_AUTHOR = "AndiEcker"                                    #: project author name default
@@ -269,9 +271,11 @@ def _compile_setup_kwargs(pev: PevType):
     if 'zip_safe' not in kwargs:
         kwargs['zip_safe'] = not bool(pev['project_resources'])
     if 'extras_require' not in kwargs:
-        kwargs['extras_require'] = {'docs': pev['docs_require'],
-                                    'tests': pev['tests_require'],
-                                    'dev': pev['docs_require'] + pev['tests_require']}                  # type: ignore
+        doc_req = cast(List[str], pev['docs_require'])
+        tst_req = cast(List[str], pev['tests_require'])
+        kwargs['extras_require'] = {'dev': cast(List[str], pev['dev_require']) + doc_req + tst_req,
+                                    'docs': doc_req,
+                                    'tests': tst_req}                              # type: ignore
 
 
 def _init_app_configs(pev: PevType, cae: Any):
@@ -376,8 +380,10 @@ def _load_requirements(pev: PevType):
     """ load requirements from the available *requirements.txt file(s) of this project.
 
     :param pev:                 dict of project environment variables; with the following required project env vars:
-                                REQ_FILE_NAME, REQ_TEST_FILE_NAME, namespace_name, package_name, project_path.
-                                the project env vars that get overwritten in `pev` by this function are:
+                                DOCS_FOLDER, REQ_FILE_NAME, REQ_DEV_FILE_NAME, TESTS_FOLDER,
+                                namespace_name, package_name, project_path.
+
+                                the project env vars that get overwritten in `pev` by this function are: dev_require,
                                 docs_require, install_require, portions_packages, setup_require, tests_require.
     """
     def _package_list(req_file: str) -> List[str]:
@@ -391,15 +397,19 @@ def _load_requirements(pev: PevType):
     namespace_name = pev_str(pev, 'namespace_name')
     package_name = pev_str(pev, 'package_name')
     project_path = pev_str(pev, 'project_path')
+    req_file_name = pev_str(pev, 'REQ_FILE_NAME')
+
+    pev['dev_require'] = dev_require = _package_list(os.path.join(project_path, pev_str(pev, 'REQ_DEV_FILE_NAME')))
+    prefix = f'{namespace_name}_'
+    pev['portions_packages'] = [_ for _ in dev_require if _.startswith(prefix)]
+
+    pev['docs_require'] = _package_list(os.path.join(project_path, pev_str(pev, 'DOCS_FOLDER'), req_file_name))
+
+    pev['install_require'] = _package_list(os.path.join(project_path, req_file_name))
 
     pev['setup_require'] = [_ for _ in ('ae_base', 'de_setup_project') if _ != package_name]
 
-    pev['install_require'] = min_require = _package_list(os.path.join(project_path, pev_str(pev, 'REQ_FILE_NAME')))
-    prefix = f'{namespace_name}_'
-    pev['portions_packages'] = [_ for _ in min_require if _.startswith(prefix)]
-
-    pev['tests_require'] = tests_require = _package_list(os.path.join(project_path, pev_str(pev, 'REQ_TEST_FILE_NAME')))
-    pev['docs_require'] = [_ for _ in tests_require if _.startswith('sphinx')]
+    pev['tests_require'] = _package_list(os.path.join(project_path, pev_str(pev, 'TESTS_FOLDER'), req_file_name))
 
 
 def _sync_stk_to_setup_kwargs(pev: PevType):
